@@ -47,7 +47,8 @@ def findMatchingTag(completion, key_string, cursor, column):
 
 class GnomoliciousApplet(gnome.applet.Applet):
     
-    title_re = re.compile('<title>(?P<title>.*)</title>', re.IGNORECASE)
+    title_re = re.compile('<title>(?P<title>.*)</title>',
+            re.IGNORECASE|re.DOTALL)
     
     def __init__(self, applet, iid):
         self.last_update = 0
@@ -191,8 +192,10 @@ class GnomoliciousApplet(gnome.applet.Applet):
     def on_dragdata_received(self, widget, context, x, y, selection, ttype,
             time):
         url = selection.data
+        logger.info('Received url: %s' % url)
         txt = urllib.urlopen(url).read()
         title = self.title_re.search(txt).groupdict()['title']
+        title = ' '.join(title.split())
         self.postwin.entries['url'].set_text(url)
         self.postwin.entries['desc'].set_text(title)
         self.update_tags()
